"""
    EMIL GdvService

    The EMIL GdvService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.accounting
from eis.accounting.model.zip_code_class import ZipCodeClass
globals()['ZipCodeClass'] = ZipCodeClass
from eis.accounting.model.store_zip_codes_response_class import StoreZipCodesResponseClass


class TestStoreZipCodesResponseClass(unittest.TestCase):
    """StoreZipCodesResponseClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStoreZipCodesResponseClass(self):
        """Test StoreZipCodesResponseClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = StoreZipCodesResponseClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
